@@ -79,6 +79,13 @@ void output_header(Project* project, char* title, char* script_name, NaviType na
             "<body>\n"
             "<a name=\"top\"></a>\n"
             "<h1 id=\"toptitle\" title=\"Starbug1\"><a href=\"http://starbug1.sourceforge.jp/\"><img src=\"%s/../index.%s/%s/setting_file/top_image\" alt=\"Starbug1\" /></a></h1>\n", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url);
+    o(      "<div id='pankuzu'>\n"
+            "<ul>\n");
+    o(      "\t<li><a href='%s/top/' title=\"%s\">%s</a> &gt; </li>\n", cgiScriptName, _("display sub projects list at top page."), _("top page"));
+    o(      "\t<li><a href='%s/../index.%s/%s'>", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url); h(string_rawstr(project->name)); o("</a></li>\n"); 
+    o(      "</ul>\n"
+            "<br clear='all' />\n"
+            "</div>\n");
     o(      "<div id='menu'>\n"
             "<ul>\n");
     o(      "\t<li><a href=\"%s/../index.%s/top/\" title=\"%s\">%s</a></li>\n",
@@ -110,7 +117,7 @@ void output_footer()
             "\t</a>\n"
             "</p>\n"
             "<div><address>Powered by cgic &amp; SQLite3.</address></div>\n"
-            "<div><address>Starbug1 version: %s. %s.</address></div>\n"
+            "<div><address><a href=\"http://starbug1.sourceforge.jp/\">Starbug1</a> version: %s. %s.</address></div>\n"
             "</div>\n"
             "</div>\n"
             "</body>\n</html>\n", cgiScriptName, VERSION, COPYRIGHT);
@@ -389,6 +396,9 @@ void items_action()
             case ELEM_TYPE_LIST_SINGLE:
                 o(_("selection list(select)"));
                 break;
+            case ELEM_TYPE_LIST_SINGLE_RADIO:
+                o(_("selection list(input[type=radio])"));
+                break;
             case ELEM_TYPE_LIST_MULTI:
                 o(_("multi selection list(select[multiple=multiple])"));
                 break;
@@ -403,6 +413,7 @@ void items_action()
         o("\t\t\t</tr>\n");
         switch (et->type) {
             case ELEM_TYPE_LIST_SINGLE:
+            case ELEM_TYPE_LIST_SINGLE_RADIO:
             case ELEM_TYPE_LIST_MULTI:
                 o("\t\t\t<tr>\n"
                   "\t\t\t\t<th>%s</th>\n"
@@ -598,6 +609,7 @@ void update_elements(Database* db)
         /* list_item */
         switch (et_a->type) {
             case ELEM_TYPE_LIST_SINGLE:
+            case ELEM_TYPE_LIST_SINGLE_RADIO:
             case ELEM_TYPE_LIST_MULTI:
                 /* 選択要素のあるelementだけ、list_itemの更新を行なう。 */
                 list_alloc(items_a, ListItem, list_item_new, list_item_free);
@@ -733,6 +745,10 @@ void new_item_action()
             "type=\"radio\" name=\"field.type\" ", ELEM_TYPE_LIST_SINGLE);
     o(                  "value=\"%d\" />\n", ELEM_TYPE_LIST_SINGLE);
     o("\t\t\t\t\t<label for=\"field.type%d\">%s</label><br />\n", ELEM_TYPE_LIST_SINGLE, _("selection list(select)"));
+    o("\t\t\t\t\t<input id=\"field.type%d\" class=\"radio\" "
+            "type=\"radio\" name=\"field.type\" ", ELEM_TYPE_LIST_SINGLE_RADIO);
+    o(                  "value=\"%d\" />\n", ELEM_TYPE_LIST_SINGLE_RADIO);
+    o("\t\t\t\t\t<label for=\"field.type%d\">%s</label><br />\n", ELEM_TYPE_LIST_SINGLE_RADIO, _("selection list(input[type=radio])"));
     o("\t\t\t\t\t<input id=\"field.type%d\" class=\"radio\" "
             "type=\"radio\" name=\"field.type\" ", ELEM_TYPE_LIST_MULTI);
     o(                  "value=\"%d\" />\n", ELEM_TYPE_LIST_MULTI);
@@ -835,6 +851,7 @@ void new_item_submit_action()
     e_type_id = db_register_element_type(db_a, et_a);
     switch (et_a->type) {
         case ELEM_TYPE_LIST_SINGLE:
+        case ELEM_TYPE_LIST_SINGLE_RADIO:
         case ELEM_TYPE_LIST_MULTI:
             for (i = 0; i < ADD_ITEM_COUNT; i++) {
                 char name[DEFAULT_LENGTH];
@@ -957,7 +974,7 @@ void style_action()
         element_types_a = db_get_element_types_all(db_a, NULL, element_types_a);
         foreach (it, element_types_a) {
             ElementType* et = it->element;
-            if (et->type == ELEM_TYPE_LIST_SINGLE && et->display_in_list) {
+            if ((et->type == ELEM_TYPE_LIST_SINGLE || et->type == ELEM_TYPE_LIST_SINGLE_RADIO) && et->display_in_list) {
                 List* items_a;
                 Iterator* it_item;
                 list_alloc(items_a, ListItem, list_item_new, list_item_free);
