@@ -4,13 +4,13 @@
 
 #include <stdio.h>
 #include "list.h"
+#include "simple_string.h"
 
 #define VALUE_LENGTH 1048575
 #define MODE_LENGTH 10
 #define DEFAULT_LENGTH 1024
 #define NUM_LENGTH 20
 #define DATE_LENGTH 20
-#define MAX_FILE_SIZE 512
 #define LIST_COUNT_PER_LIST_PAGE 15
 #define LIST_COUNT_PER_SEARCH_PAGE 30
 
@@ -19,79 +19,97 @@ typedef enum _bool {
     true
 } bool;
 
-typedef struct _project {
-  char name[DEFAULT_LENGTH];
-  char home_url[DEFAULT_LENGTH];
+typedef struct {
+    int id;
+    String* code;
+    int sort;
+    int deleted;
+} ProjectInfo;
+ProjectInfo* project_info_new();
+void project_info_free(ProjectInfo*);
+
+typedef struct {
+    String* name;
+    String* home_description;
+    String* home_url;
+    int upload_max_size;
+    String* locale;
 } Project;
 Project* project_new();
 void project_free(Project*);
 
-typedef struct _element {
-  int element_type_id;
-  char* str_val;
-  int is_file;
+typedef struct {
+    int element_type_id;
+    String* str_val;
+    int is_file;
 } Element;
+Element* element_new();
+void element_free(Element*);
 
-typedef struct _setting_file {
-    char name[DEFAULT_LENGTH];
-    char file_name[DEFAULT_LENGTH];
+typedef struct {
+    String* name;
+    String* file_name;
     int size;
-    char mime_type[DEFAULT_LENGTH];
+    String* mime_type;
     char* content;
 } SettingFile;
 SettingFile* setting_file_new();
 void setting_file_free(SettingFile*);
 
-typedef struct _message {
-  int id;
-  List* elements;
+typedef struct {
+    int id;
+    List* elements;
 } Message;
 Message* message_new();
 void message_free(Message*);
 
-typedef struct _list_item {
-  int id;
-  int element_type_id;
-  char name[256];
-  int close;
-  int sort;
+typedef struct {
+    int id;
+    int element_type_id;
+    String* name;
+    int close;
+    int sort;
 } ListItem;
 ListItem* list_item_new();
 void list_item_free(ListItem*);
 
-typedef struct _element_type {
-  int id;
-  int type;
-  int ticket_property;
-  int reply_property;
-  int required;
-  char name[DEFAULT_LENGTH];
-  char description[DEFAULT_LENGTH];
-  int auto_add_item;
-  char default_value[DEFAULT_LENGTH];
-  int display_in_list;
-  int sort;
+typedef struct {
+    int id;
+    int type;
+    int ticket_property;
+    int reply_property;
+    int required;
+    String* name;
+    String* description;
+    int auto_add_item;
+    String* default_value;
+    int display_in_list;
+    int sort;
 } ElementType;
+ElementType* element_type_new();
+void element_type_free(ElementType*);
 
-typedef struct _element_file {
+typedef struct {
     int id;
     int element_type_id;
-    char name[DEFAULT_LENGTH];
+    String* name;
     int size;
-    char mime_type[DEFAULT_LENGTH];
+    String* mime_type;
     char* content;
 } ElementFile;
 ElementFile* element_file_new();
 void element_file_free(ElementFile*);
 
 enum ELEM_TYPE {
-  ELEM_TYPE_TEXT,
-  ELEM_TYPE_TEXTAREA,
-  ELEM_TYPE_CHECKBOX,
-  ELEM_TYPE_LIST_SINGLE,
-  ELEM_TYPE_LIST_MULTI,
-  ELEM_TYPE_UPLOADFILE,
-  ELEM_TYPE_DATE
+    ELEM_TYPE_TEXT,
+    ELEM_TYPE_TEXTAREA,
+    ELEM_TYPE_CHECKBOX,
+    ELEM_TYPE_LIST_SINGLE,
+    ELEM_TYPE_LIST_MULTI,
+    ELEM_TYPE_UPLOADFILE,
+    ELEM_TYPE_DATE,
+    ELEM_TYPE_LIST_SINGLE_RADIO
+    /* DBの値と連動しているので、追加する場合は、後に追加する必要がある。*/
 };
 enum ELEM_ID {
     ELEM_ID_ID = -1,
@@ -105,16 +123,17 @@ enum ELEM_ID {
 };
 #define BASIC_ELEMENT_MAX 3
 
-typedef struct _condition {
-  int element_type_id;
-  int condition_type;
-  char value[DEFAULT_LENGTH];
-  char cookie_value[DEFAULT_LENGTH];
+typedef struct {
+    int element_type_id;
+    int condition_type;
+    String* value;
+    String* cookie_value;
 } Condition;
 enum CONDITION_TYPE {
     CONDITION_TYPE_NORMAL,
     CONDITION_TYPE_DATE_FROM,
-    CONDITION_TYPE_DATE_TO
+    CONDITION_TYPE_DATE_TO,
+    CONDITION_TYPE_DAYS
 };
 Condition* condition_new();
 void condition_free(Condition*);
@@ -124,25 +143,27 @@ int valid_condition_size(List*);
 bool valid_condition(Condition*);
 char* get_condition_valid_value(Condition*);
 
-typedef struct _state {
-  int id;
-  char name[DEFAULT_LENGTH];
-  int count;
+typedef struct {
+    int id;
+    String* name;
+    int count;
 } State;
+State* state_new();
+void state_free(State*);
 
-typedef struct _search_result {
-  int hit_count;
-  int page;
-  List* messages;
-  List* states;
+typedef struct {
+    int hit_count;
+    int page;
+    List* messages;
+    List* states;
 } SearchResult;
 SearchResult* search_result_new();
 void search_result_free(SearchResult*);
 
-typedef struct _wiki {
-  int id;
-  char name[DEFAULT_LENGTH];
-  char* content;
+typedef struct {
+    int id;
+    String* name;
+    char* content;
 } Wiki;
 Wiki* wiki_new();
 void wiki_free(Wiki*);
@@ -151,9 +172,21 @@ char* get_element_value_by_id(List*, const int);
 char* get_element_value(List*, ElementType*);
 // int get_element_lid_by_id(List*, int);
 void set_element_value(Element*, const char*);
-void free_element_list(List*);
 
+typedef struct {
+    int project_id;
+    String* project_code;
+    String* project_name;
+    int id;
+    String* title;
+} Ticket;
+Ticket* ticket_new();
+void ticket_free(Ticket*);
 
+typedef struct {
+    int id;
+    int field_count;
+} DbInfo;
 
 #endif
 /* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
